@@ -6,7 +6,7 @@ containing::
     from documenteer.conf.guide import *
 """
 
-from typing import Any, Dict, List, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 from documenteer.conf import (
     DocumenteerConfig,
@@ -28,12 +28,18 @@ from documenteer.conf import (
 #     HTML builder and theme configuration
 # #API
 #     API reference configuration
+# #GRAPHVIZ
+#     Graphviz configuration
 # #MYST
 #     MyST markdown configurations
 # #MERMIAID
 #     Mermaid diagram support
 # #OPENGRAPH
 #     OpenGraph metadata support
+# #OPENAPI
+#     OpenAPI/redoc support
+# #REDIRECTS
+#     Sphinx-rediraffe support
 
 
 # Ordered as they are declared in this module
@@ -97,11 +103,19 @@ __all__ = [
     "myst_enable_extensions",
     # MERMAID
     "mermaid_output_format",
-    "mermaid_version",
     # OPENGRAPH
     "ogp_site_url",
     "ogp_site_name",
     "ogp_use_first_image",
+    # OPENAPI
+    "documenteer_openapi_generator",
+    "documenteer_openapi_path",
+    "redoc",
+    "redoc_uri",
+    # Sphinx jinja
+    "jinja_contexts",
+    # Sphinx rediraffe
+    "rediraffe_redirects",
 ]
 
 _conf = DocumenteerConfig.find_and_load()
@@ -112,7 +126,8 @@ _conf = DocumenteerConfig.find_and_load()
 # ============================================================================
 
 extensions = [
-    "myst_parser",
+    "sphinxcontrib.jquery",
+    "myst_nb",  # enables myst-parser as well
     "sphinx_copybutton",
     "sphinx_design",
     "sphinxcontrib.mermaid",
@@ -123,11 +138,19 @@ extensions = [
     "sphinx.ext.todo",
     "sphinx.ext.ifconfig",
     "sphinx-prompt",
+    "sphinx_jinja",
+    "sphinxcontrib.redoc",
+    "sphinxcontrib.youtube",
+    "sphinxext.rediraffe",
     "sphinx.ext.napoleon",
     "sphinx_autodoc_typehints",
     "sphinx_automodapi.automodapi",
     "sphinx_automodapi.smart_resolver",
-    "documenteer.sphinxext",
+    "documenteer.ext.jira",
+    "documenteer.ext.lsstdocushare",
+    "documenteer.ext.mockcoderefs",
+    "documenteer.ext.remotecodeblock",
+    "documenteer.ext.openapi",
 ]
 _conf.append_extensions(extensions)
 
@@ -144,10 +167,10 @@ copyright = _conf.copyright
 version = _conf.version
 release = version
 
+# The source file suffixes for .md and .ipynb are automatically managed by
+# myst-nb.
 source_suffix = {
     ".rst": "restructuredtext",
-    ".txt": "markdown",
-    ".md": "markdown",
 }
 
 root_doc = "index"
@@ -156,7 +179,17 @@ language = "en"
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
-exclude_patterns = ["_build", "README.rst", "README.md"]
+exclude_patterns = [
+    "_build",
+    "README.rst",
+    "README.md",
+    ".venv",
+    "venv",
+    "requirements.txt",
+    ".github",
+    ".tox",
+]
+_conf.extend_exclude_patterns(exclude_patterns)
 
 if _conf.rst_epilog_path:
     exclude_patterns.append(str(_conf.rst_epilog_path))
@@ -201,9 +234,8 @@ intersphinx_cache_limit = 5  # days
 
 linkcheck_retries = 2
 
-# Tucson IT infrastructure sometimes goes down or has TLS issues
 linkcheck_ignore = [
-    r"^https://jira.lsstcorp.org/browse/",
+    # Tucson IT infrastructure sometimes goes down or has TLS issues
     r"^https://ls.st/",
 ]
 _conf.append_linkcheck_ignore(linkcheck_ignore)
@@ -318,6 +350,22 @@ napoleon_preprocess_types = False
 napoleon_type_aliases = None
 napoleon_attr_annotations = True
 
+# ============================================================================
+# #GRAPHVIZ graphviz configuration
+# graphviz is primarily used by automodapi to create inheritance diagrams.
+# ============================================================================
+# Render inheritance diagrams in SVG
+graphviz_output_format = "svg"
+
+graphviz_dot_args = [
+    "-Nfontsize=10",
+    "-Nfontname=Helvetica Neue, Helvetica, Arial, sans-serif",
+    "-Efontsize=10",
+    "-Efontname=Helvetica Neue, Helvetica, Arial, sans-serif",
+    "-Gfontsize=10",
+    "-Gfontname=Helvetica Neue, Helvetica, Arial, sans-serif",
+]
+
 # ============================================================================
 # #MYST MyST markdown configurations
 # https://myst-parser.readthedocs.io/en/latest/syntax/optional.html
@@ -349,10 +397,6 @@ myst_enable_extensions = [
 # Mermaid CLI installation
 mermaid_output_format = "raw"
 
-# Temporary workaround for not getting mermaid 10 successfully from unpkg
-# https://github.com/mgaitan/sphinxcontrib-mermaid/issues/110
-mermaid_version = "9.4.0"
-
 # ============================================================================
 # #OPENGRAPH OpenGraph diagram support
 # https://github.com/wpilibsuite/sphinxext-opengraph
@@ -362,3 +406,50 @@ mermaid_version = "9.4.0"
 ogp_site_url = _conf.base_url
 ogp_site_name = _conf.project
 ogp_use_first_image = True
+
+# ============================================================================
+# #OPEN OpenAPI/Redoc support
+# https://sphinxcontrib-redoc.readthedocs.io/en/stable/
+# documenteer.ext.openapi
+# ============================================================================
+
+if _conf.conf.project.openapi is not None:
+    if _conf.conf.project.openapi.generator is not None:
+        documenteer_openapi_generator: Optional[Dict[str, Any]] = {
+            "func": _conf.conf.project.openapi.generator.function,
+            "args": _conf.conf.project.openapi.generator.positional_args,
+            "kwargs": _conf.conf.project.openapi.generator.keyword_args,
+        }
+    else:
+        documenteer_openapi_generator = None
+    documenteer_openapi_path: Optional[str] = (
+        _conf.conf.project.openapi.openapi_path
+    )
+    redoc: Optional[List[Any]] = [
+        {
+            "name": "REST API",
+            "page": _conf.conf.project.openapi.doc_path,
+            "spec": _conf.conf.project.openapi.openapi_path,
+            "embed": True,
+            "opts": {"hide-hostname": True},
+        }
+    ]
+    redoc_uri: Optional[str] = (
+        "https://cdn.jsdelivr.net/npm/redoc@next/bundles/redoc.standalone.js"
+    )
+else:
+    documenteer_openapi_generator = None
+    documenteer_openapi_path = None
+    redoc = []
+    redoc_uri = None
+
+# ============================================================================
+# #JINJA Sphinx Jinja support
+# ============================================================================
+jinja_contexts: dict[str, Any] = {}
+
+# ============================================================================
+# #REDIRECTS Sphinx-rediraffe support
+# https://sphinxext-rediraffe.readthedocs.io/en/latest/
+# ============================================================================
+rediraffe_redirects: dict[str, str] = _conf.redirects
