@@ -1,5 +1,4 @@
-"""Configuration and execution of Doxygen at the stack level.
-"""
+"""Configuration and execution of Doxygen at the stack level."""
 
 __all__ = [
     "DoxygenConfiguration",
