@@ -2,13 +2,7 @@
 
 __all__ = ["__version__", "version_info"]
 
-import sys
-
-if sys.version_info < (3, 8):
-    from importlib_metadata import PackageNotFoundError, version
-else:
-    from importlib.metadata import PackageNotFoundError, version
-
+from importlib.metadata import PackageNotFoundError, version
 
 __version__: str
 """The version string of Documenteer (PEP 440 / SemVer compatible)."""
@@ -21,5 +15,6 @@ except PackageNotFoundError:
 
 version_info = __version__.split(".")
 """The decomposed version, split across "``.``."
+
 Use this for version comparison.
 """
