@@ -82,7 +82,7 @@ disable_primary_sidebars = [
 def test_load() -> None:
     config = DocumenteerConfig.load(EXAMPLE)
     assert config.project == "Documenteer"
-    assert config.base_url == "https://documenteer.lsst.io"
+    assert config.base_url == "https://documenteer.lsst.io/"
     assert config.copyright == "2022 AURA"
     assert config.github_url == "https://github.com/lsst-sqre/documenteer"
     assert config.version == "1.0.0"
@@ -110,13 +110,13 @@ def test_append_extensions() -> None:
     existing_extensions = [
         "sphinx_design",
         "sphinx.ext.autodoc",
-        "documenteer.sphinxext",
+        "documenteer.ext.jira",
     ]
     config.append_extensions(existing_extensions)
     assert existing_extensions == [
         "sphinx_design",
         "sphinx.ext.autodoc",
-        "documenteer.sphinxext",
+        "documenteer.ext.jira",
         "new_extension",
     ]
 
@@ -131,7 +131,7 @@ def test_append_intersphinx_projects() -> None:
     assert projects == {
         "python": ("https://docs.python.org/3/", None),
         "sphinx": ("https://www.sphinx-doc.org/en/master/", None),
-        "documenteer": ("https://documenteer.lsst.io", None),
+        "documenteer": ("https://documenteer.lsst.io/", None),
     }
 
 
@@ -139,12 +139,12 @@ def test_append_linkcheck_ignore() -> None:
     config = DocumenteerConfig.load(EXAMPLE)
 
     linkcheck_ignore = [
-        r"^https://jira.lsstcorp.org/browse/",
+        r"^https://rubinobs.atlassian.net/browse/",
         r"^https://ls.st/",
     ]
     config.append_linkcheck_ignore(linkcheck_ignore)
     assert linkcheck_ignore == [
-        r"^https://jira.lsstcorp.org/browse/",
+        r"^https://rubinobs.atlassian.net/browse/",
         r"^https://ls.st/",
         r"^https://confluence.lsstcorp.org/",
     ]
